CompletionReport class
Provides a report detailing the data repository task results of the files
processed that match the criteria specified in the report Scope
parameter. FSx delivers the report to the file system's linked data
repository in Amazon S3, using the path specified in the report
Path parameter. You can specify whether or not a report gets
generated for a task using the Enabled parameter.
Constructors
- CompletionReport({required bool enabled, ReportFormat? format, String? path, ReportScope? scope})
-
CompletionReport.fromJson(Map<
String, dynamic> json) -
factory
Properties
- enabled → bool
-
Set
EnabledtoTrueto generate aCompletionReportwhen the task completes. If set totrue, then you need to provide a reportScope,Path, andFormat. SetEnabledtoFalseif you do not want aCompletionReportgenerated when the task completes.final - format → ReportFormat?
-
Required if
Enabledis set totrue. Specifies the format of theCompletionReport.REPORT_CSV_20191124is the only format currently supported. WhenFormatis set toREPORT_CSV_20191124, theCompletionReportis provided in CSV format, and is delivered to{path}/task-{id}/failures.csv.final - hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
Required if
Enabledis set totrue. Specifies the location of the report on the file system's linked S3 data repository. An absolute path that defines where the completion report will be stored in the destination location. ThePathyou provide must be located within the file system’s ExportPath. An examplePathvalue is "s3://myBucket/myExportPath/optionalPrefix". The report provides the following information for each file in the report: FilePath, FileStatus, and ErrorCode. To learn more about a file system'sExportPath, see .final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → ReportScope?
-
Required if
Enabledis set totrue. Specifies the scope of theCompletionReport;FAILED_FILES_ONLYis the only scope currently supported. WhenScopeis set toFAILED_FILES_ONLY, theCompletionReportonly contains information about files that the data repository task failed to process.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited